@@ -15,9 +15,11 @@ class _Client:
         '__make__',
         'websocket',
         'utils',
+        '__auth',
     )
     def __init__(self, auth):
         self.__make__ = MethodsMaker(auth=auth,)
+        self.__auth = auth
         self.websocket = WebSocket(auth,).updatesHandler
         self.utils = Utils()
         del auth
@@ -44,7 +46,6 @@ class _Client:
             method='sendMessage',
             data=data,
         )
-        print(data)
         return data
 
     async def sendText(self, object_guid, text, reply_to_message_id=None,):
@@ -471,7 +472,7 @@ class _Client:
         data = {'channel_guid': channel_guid, 'member_guids': member_guids}
         return await self.__make__.request('addChannelMembers', data,)
 
-    async def getChannelAllMembers(self, channel_guid, search_text, start_id=None):
+    async def getChannelAllMembers(self, channel_guid, search_text=None, start_id=None):
         data = {'channel_guid': channel_guid, 'search_text': search_text, 'start_id': start_id}
         return await self.__make__.request('getChannelAllMembers', data,)
 
@@ -509,6 +510,9 @@ class _Client:
     async def getContacts(self):
         return await self.__make__.request('getContacts', {})
 
+    async def deleteContact(self):
+        pass
+
     # settings
     async def addFolder(
         self,
@@ -690,13 +694,13 @@ class _Client:
         )
 
     async def download(self, object_guid=None, message_id=None, from_link=None, save=False, file_name=None, **kwargs):
-        file = b''
-
         file_id = kwargs.get('file_id')
+
         if file_id != None:
             size = kwargs.get('size')
             dc_id = kwargs.get('dc_id')
             access_hash_rec = kwargs.get('access_hash_rec')
+
         elif from_link != None and from_link.startswith('http'):
             geted_data = await self.getLinkFromAppUrl(from_link)
             geted_data = geted_data.get('link').get('open_chat_data')
@@ -707,6 +711,7 @@ class _Client:
             dc_id = message_data.get('dc_id')
             access_hash_rec = message_data.get('access_hash_rec')
             file_name = message_data.get('file_name')
+
         elif object_guid and message_id != None:
             geted_data = await self.getMessagesByID(object_guid, [message_id])
             message_data = geted_data.get('messages')[0].get('file_inline')
@@ -718,7 +723,7 @@ class _Client:
 
         url = 'https://messenger{}.iranlms.ir/GetFile.ashx'.format(dc_id)
         headers = {
-            'auth': self._auth,
+            'auth': self.__auth,
             'file-id': file_id,
 			'access-hash-rec': access_hash_rec
         }
@@ -751,12 +756,10 @@ class _Client:
 
     def Handler(self, func):
         async def runner():
+            print('This method will be removed in the update version 5.1.0 and later, please use newUpdatesHandler')
             async for i in self.websocket():
                 await func(Message(self, i))
         RUN(runner())
-        raise RuntimeWarning(
-            'This method will be removed in the update version 5.0.3 and later, please use newUpdatesHandler'
-            )
 
     def run(self, func):
         RUN(func())
\ No newline at end of file
